@@ -87,7 +87,7 @@ function PMA_getColumnsInfo()
         $fields_rs = $GLOBALS['dbi']->query(
             $GLOBALS['dbi']->getColumnsSql(
                 $GLOBALS['db'],
-                $GLOBALS['PMD']["TABLE_NAME_SMALL"][$i],
+                $GLOBALS['PMD_URL']["TABLE_NAME_SMALL"][$i],
                 null,
                 true
             ),
@@ -363,7 +363,7 @@ function PMA_getDefaultPage($db)
         PMA\libraries\DatabaseInterface::QUERY_STORE
     );
 
-    if (count($default_page_no)) {
+    if (isset($default_page_no) && count($default_page_no)) {
         return intval($default_page_no[0]);
     }
     return -1;
@@ -402,7 +402,7 @@ function PMA_getLoadingPage($db)
             $GLOBALS['controllink'],
             PMA\libraries\DatabaseInterface::QUERY_STORE
         );
-        if (count($min_page_no[0])) {
+        if (isset($min_page_no[0]) && count($min_page_no[0])) {
             $page_no = $min_page_no[0];
         }
     }
@@ -506,13 +506,8 @@ function PMA_saveDisplayField($db, $table, $field)
         return false;
     }
 
-    $disp = PMA_getDisplayField($db, $table);
-    if ($disp && $disp === $field) {
-        $field = '';
-    }
-
     $upd_query = new Table($table, $db, $GLOBALS['dbi']);
-    $upd_query->updateDisplayField($disp, $field, $cfgRelation);
+    $upd_query->updateDisplayField($field, $cfgRelation);
 
     return true;
 }
